pub(crate) struct ClientTicketRequest {
pub new_session_count: u8,
pub resumption_count: u8,
}Expand description
RFC 9149: ClientTicketRequest extension payload.
Fields
new_session_count: u8Tickets desired when the server negotiates a new connection.
resumption_count: u8Tickets desired when the server resumes using a presented ticket.