pub(crate) struct ServerTicketRequestHint {
pub(crate) expected_count: u8,
}Expand description
RFC 9149: ServerTicketRequestHint extension payload.
Fields
expected_count: u8Trait Implementations
Sourceimpl Clone for ServerTicketRequestHint
impl Clone for ServerTicketRequestHint
Sourcefn clone(&self) -> ServerTicketRequestHint
fn clone(&self) -> ServerTicketRequestHint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Codec<'_> for ServerTicketRequestHint
impl Codec<'_> for ServerTicketRequestHint
Sourcefn encode(&self, bytes: &mut Vec<u8>)
fn encode(&self, bytes: &mut Vec<u8>)
Function for encoding itself by appending itself to
the provided vec of bytes.
Sourcefn read(r: &mut Reader<'_>) -> Result<Self, InvalidMessage>
fn read(r: &mut Reader<'_>) -> Result<Self, InvalidMessage>
Function for decoding itself from the provided reader
will return Some if the decoding was successful or
None if it was not.
Sourcefn get_encoding(&self) -> Vec<u8> ⓘ
fn get_encoding(&self) -> Vec<u8> ⓘ
Convenience function for encoding the implementation
into a vec and returning it
Sourcefn read_bytes(bytes: &'a [u8]) -> Result<Self, InvalidMessage>
fn read_bytes(bytes: &'a [u8]) -> Result<Self, InvalidMessage>
Function for wrapping a call to the read function in
a Reader for the slice of bytes provided Read more
Sourceimpl Debug for ServerTicketRequestHint
impl Debug for ServerTicketRequestHint
Sourceimpl PartialEq for ServerTicketRequestHint
impl PartialEq for ServerTicketRequestHint
impl Copy for ServerTicketRequestHint
impl StructuralPartialEq for ServerTicketRequestHint